.. sushy documentation master file, created by
   sphinx-quickstart on Tue Jul 9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=================================
Welcome to Sushy's documentation!
=================================

.. include:: ../../README.rst

Documentation
=============

.. toctree::
   :maxdepth: 1

   install/index
   contributor/index
   reference/index

* :ref:`genindex`
